==> konclude_0.6.2+939~dfsg.orig.tar.xz: Konclude-0.6.2-939/Source/Reasoner/Revision/Persistence/CConfigurationBasedOntologyRevisionPersistencerFactory.cpp <==
/*
 *		Copyright (C) 2013-2015, 2019 by the Konclude Developer Team.
 *
 *		This file is part of the reasoning system Konclude.
 *		For details and support, see <http://konclude.com/>.
 *
 *		Konclude is free software: you can redistribute it and/or modify
 *		it under the terms of version 3 of the GNU Lesser General Public
 *		License (LGPLv3) as published by the Free Software Foundation.
 *
 *		Konclude is distributed in the hope that it will be useful,
 *		but WITHOUT ANY WARRANTY; without even the implied warranty of
 *		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *		GNU (Lesser) General Public License for more details.
 *
 *		You should have received a copy of the GNU (Lesser) General Public
 *		License along with Konclude. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "CConfigurationBasedOntologyRevisionPersistencerFactory.h"


namespace Konclude {

	namespace Reasoner {

		namespace Revision {

			namespace Persistence {

				CConfigurationBasedOntologyRevisionPersistencerFactory::CConfigurationBasedOntologyRevisionPersistencerFactory(CConfiguration* config) {
					mConfig = config;
				}

				
				COntologyRevisionPersistencer* CConfigurationBasedOntologyRevisionPersistencerFactory::createOntologyRevisionPersistencer() {
					COntologyRevisionPersistencer* persistencer = nullptr;
					QString persistencerName = CConfigDataReader::readConfigString(mConfig,"Konclude.Persistence.OntologyRevisionPersistencer");
					if (persistencerName == "Konclude.Persistence.DirectoryOWL2XMLFilePersistencer") {
						persistencer = new COntologyRevisionDirectoryOWL2XMLFilePersistencer(mConfig);
					}
					return persistencer;
				}

			}; // end namespace Persistence

		}; // end namespace Revision

	}; // end namespace Reasoner

}; // end namespace Konclude

==> konclude_0.7.0+1137~dfsg.orig.tar.xz: Konclude-0.7.0-1137/Source/Reasoner/Revision/Persistence/CConfigurationBasedOntologyRevisionPersistencerFactory.cpp <==
/*
 *		Copyright (C) 2013-2015, 2019 by the Konclude Developer Team.
 *
 *		This file is part of the reasoning system Konclude.
 *		For details and support, see <http://konclude.com/>.
 *
 *		Konclude is free software: you can redistribute it and/or modify
 *		it under the terms of version 3 of the GNU Lesser General Public
 *		License (LGPLv3) as published by the Free Software Foundation.
 *
 *		Konclude is distributed in the hope that it will be useful,
 *		but WITHOUT ANY WARRANTY; without even the implied warranty of
 *		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *		GNU (Lesser) General Public License for more details.
 *
 *		You should have received a copy of the GNU (Lesser) General Public
 *		License along with Konclude. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "CConfigurationBasedOntologyRevisionPersistencerFactory.h"


namespace Konclude {

	namespace Reasoner {

		namespace Revision {

			namespace Persistence {

				CConfigurationBasedOntologyRevisionPersistencerFactory::CConfigurationBasedOntologyRevisionPersistencerFactory(CConfiguration* config) {
					mConfig = config;
				}

				
				COntologyRevisionPersistencer* CConfigurationBasedOntologyRevisionPersistencerFactory::createOntologyRevisionPersistencer() {
					COntologyRevisionPersistencer* persistencer = nullptr;
					QString persistencerName = CConfigDataReader::readConfigString(mConfig,"Konclude.Persistence.OntologyRevisionPersistencer");
					CNameBasedOntologyRevisionPersistencerFactory nameFactory(persistencerName, mConfig);
					persistencer = nameFactory.createOntologyRevisionPersistencer();
					return persistencer;
				}

			}; // end namespace Persistence

		}; // end namespace Revision

	}; // end namespace Reasoner

}; // end namespace Konclude
